Module accounts

Module accounts 

An Anchor generated module, providing a set of structs mirroring the structs deriving Accounts, where each field is a Pubkey. This is useful for specifying accounts for a client.

Structs

AddAssetMemberInstructionAccounts
Generated client accounts for AddAssetMemberInstructionAccounts.
AddAssetMintInstructionAccounts
Generated client accounts for AddAssetMintInstructionAccounts.
AddAssetTokenInstructionAccounts
Generated client accounts for AddAssetTokenInstructionAccounts.
AddGroupMemberInstructionAccounts
Generated client accounts for AddGroupMemberInstructionAccounts.
AddMemberInResetModeAccounts
Generated client accounts for AddMemberInResetModeAccounts.
ChangeAssetConfigInstructionAccounts
Generated client accounts for ChangeAssetConfigInstructionAccounts.
ChangeGroupConfigInstructionAccounts
Generated client accounts for ChangeGroupConfigInstructionAccounts.
CleanUpAssetMemberInstructionAccounts
Generated client accounts for CleanUpAssetMemberInstructionAccounts.
CloseConfigVoteRecordInstructionAccounts
Generated client accounts for CloseConfigVoteRecordInstructionAccounts.
CloseEmergencyResetProposalAccounts
Generated client accounts for CloseEmergencyResetProposalAccounts.
CloseEmergencyResetVoteRecordAccounts
Generated client accounts for CloseEmergencyResetVoteRecordAccounts.
CloseNormalProposalInstructionAccounts
Generated client accounts for CloseNormalProposalInstructionAccounts.
CloseNormalVoteRecordInstructionAccounts
Generated client accounts for CloseNormalVoteRecordInstructionAccounts.
CloseProposalInstructionAccounts
Generated client accounts for CloseProposalInstructionAccounts.
CloseProposalTransactionInstructionAccounts
Generated client accounts for CloseProposalTransactionInstructionAccounts.
CreateConfigProposalInstructionAccounts
Generated client accounts for CreateConfigProposalInstructionAccounts.
CreateEmergencyResetProposalAccounts
Generated client accounts for CreateEmergencyResetProposalAccounts.
CreateGroupInstructionAccounts
Generated client accounts for CreateGroupInstructionAccounts.
CreateNormalProposalInstructionAccounts
Generated client accounts for CreateNormalProposalInstructionAccounts.
CreateProposalTransactionInstructionAccounts
Generated client accounts for CreateProposalTransactionInstructionAccounts.
ExecuteEmergencyResetAccounts
Generated client accounts for ExecuteEmergencyResetAccounts.
ExecuteProposalTransactionInstructionAccounts
Generated client accounts for ExecuteProposalTransactionInstructionAccounts.
ExitPauseModeAccounts
Generated client accounts for ExitPauseModeAccounts.
RemoveAssetMemberInstructionAccounts
Generated client accounts for RemoveAssetMemberInstructionAccounts.
RemoveGroupMemberInstructionAccounts
Generated client accounts for RemoveGroupMemberInstructionAccounts.
RemoveMemberInResetModeAccounts
Generated client accounts for RemoveMemberInResetModeAccounts.
VoteOnConfigProposalInstructionAccounts
Generated client accounts for VoteOnConfigProposalInstructionAccounts.
VoteOnEmergencyResetAccounts
Generated client accounts for VoteOnEmergencyResetAccounts.
VoteOnNormalProposalInstructionAccounts
Generated client accounts for VoteOnNormalProposalInstructionAccounts.