pub struct AddAssetMintInstructionAccounts {Show 14 fields
pub payer: Pubkey,
pub group: Pubkey,
pub mint: Pubkey,
pub asset: Pubkey,
pub asset_authority: Pubkey,
pub adder: Pubkey,
pub group_member_1: Pubkey,
pub group_member_2: Pubkey,
pub group_member_3: Pubkey,
pub asset_member_1: Pubkey,
pub asset_member_2: Pubkey,
pub asset_member_3: Pubkey,
pub token_program: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for AddAssetMintInstructionAccounts.
Fields
payer: Pubkeygroup: Pubkeymint: Pubkeyasset: Pubkeyadder: Pubkeygroup_member_1: Pubkeygroup_member_2: Pubkeygroup_member_3: Pubkeyasset_member_1: Pubkeyasset_member_2: Pubkeyasset_member_3: Pubkeytoken_program: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for AddAssetMintInstructionAccountswhere
Pubkey: BorshSerialize,
impl BorshSerialize for AddAssetMintInstructionAccountswhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for AddAssetMintInstructionAccounts
impl ToAccountMetas for AddAssetMintInstructionAccounts
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for AddAssetMintInstructionAccounts
impl RefUnwindSafe for AddAssetMintInstructionAccounts
impl Send for AddAssetMintInstructionAccounts
impl Sync for AddAssetMintInstructionAccounts
impl Unpin for AddAssetMintInstructionAccounts
impl UnsafeUnpin for AddAssetMintInstructionAccounts
impl UnwindSafe for AddAssetMintInstructionAccounts