pub struct AddMemberInResetModeAccounts {
pub group: Pubkey,
pub new_member_account: Pubkey,
pub trusted_1: Pubkey,
pub trusted_2: Pubkey,
pub trusted_3: Pubkey,
pub payer: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for AddMemberInResetModeAccounts.
Fields
group: Pubkeynew_member_account: Pubkeytrusted_1: Pubkeytrusted_2: Pubkeytrusted_3: Pubkeypayer: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for AddMemberInResetModeAccountswhere
Pubkey: BorshSerialize,
impl BorshSerialize for AddMemberInResetModeAccountswhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for AddMemberInResetModeAccounts
impl ToAccountMetas for AddMemberInResetModeAccounts
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for AddMemberInResetModeAccounts
impl RefUnwindSafe for AddMemberInResetModeAccounts
impl Send for AddMemberInResetModeAccounts
impl Sync for AddMemberInResetModeAccounts
impl Unpin for AddMemberInResetModeAccounts
impl UnsafeUnpin for AddMemberInResetModeAccounts
impl UnwindSafe for AddMemberInResetModeAccounts