pub struct CloseConfigVoteRecordInstructionAccounts {
pub group: Pubkey,
pub proposal: Pubkey,
pub vote_record: Pubkey,
pub voter: Pubkey,
}Expand description
Generated client accounts for CloseConfigVoteRecordInstructionAccounts.
Fields
group: Pubkeyproposal: Pubkeyvote_record: Pubkeyvoter: PubkeyTrait Implementations
Sourceimpl BorshSerialize for CloseConfigVoteRecordInstructionAccountswhere
Pubkey: BorshSerialize,
impl BorshSerialize for CloseConfigVoteRecordInstructionAccountswhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for CloseConfigVoteRecordInstructionAccounts
impl ToAccountMetas for CloseConfigVoteRecordInstructionAccounts
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for CloseConfigVoteRecordInstructionAccounts
impl RefUnwindSafe for CloseConfigVoteRecordInstructionAccounts
impl Send for CloseConfigVoteRecordInstructionAccounts
impl Sync for CloseConfigVoteRecordInstructionAccounts
impl Unpin for CloseConfigVoteRecordInstructionAccounts
impl UnsafeUnpin for CloseConfigVoteRecordInstructionAccounts
impl UnwindSafe for CloseConfigVoteRecordInstructionAccounts