pub fn execute_proposal_transaction_handler(
ctx: Context<'_, '_, '_, '_, ExecuteProposalTransactionInstructionAccounts<'_>>,
) -> Result<()>Expand description
Executes the transaction attached to a passed normal proposal.
pub fn execute_proposal_transaction_handler(
ctx: Context<'_, '_, '_, '_, ExecuteProposalTransactionInstructionAccounts<'_>>,
) -> Result<()>Executes the transaction attached to a passed normal proposal.