NormalProposal

Struct NormalProposal 

pub struct NormalProposal {
Show 13 fields pub assets: Vec<ProposalAsset>, pub instruction_hashes: Vec<[u8; 32]>, pub propose_timestamp: i64, pub proposal_deadline_timestamp: i64, pub proposal_passed_timestamp: Option<i64>, pub proposal_index: u64, pub timelock_offset: u32, pub group: Pubkey, pub proposer: Pubkey, pub proposal_seed: Pubkey, pub passed_assets_count: u8, pub state: ProposalState, pub account_bump: u8,
}

Fields

assets: Vec<ProposalAsset>instruction_hashes: Vec<[u8; 32]>

Hashes of each instruction in the proposal transaction, in order.

propose_timestamp: i64proposal_deadline_timestamp: i64proposal_passed_timestamp: Option<i64>proposal_index: u64timelock_offset: u32group: Pubkeyproposer: Pubkeyproposal_seed: Pubkeypassed_assets_count: u8state: ProposalStateaccount_bump: u8

Implementations

Source

impl NormalProposal

pub fn new( proposer: Pubkey, proposal_seed: Pubkey, group: Pubkey, assets: Vec<ProposalAsset>, account_bump: u8, proposal_index: u64, proposal_deadline_timestamp: i64, instruction_hashes: Vec<[u8; 32]>, timelock_offset: u32, ) -> Result<Self>

pub fn get_asset_mut(&mut self, index: usize) -> Option<&mut ProposalAsset>

pub fn increment_passed_assets_count(&mut self) -> Result<()>

pub fn has_all_assets_passed(&self) -> bool

pub fn set_proposal_passed_timestamp(&mut self, timestamp: i64)

pub fn get_valid_from_timestamp(&self) -> Result<i64>

pub fn set_state(&mut self, new_state: ProposalState) -> Result<()>

pub fn mark_executed(&mut self) -> Result<()>

pub fn get_size(asset_count: usize, instruction_hash_count: usize) -> usize

pub fn check_and_mark_asset_passed( &mut self, index: usize, governed_asset: &Account<'_, Asset>, ) -> Result<bool>

Check if an asset has enough support to be marked as passed and pass the proposal if possible

pub fn check_and_mark_asset_failed( &mut self, index: usize, governed_asset: &Account<'_, Asset>, ) -> Result<bool>

Check if an asset has enough opposition to be marked as failed and fail the proposal if possible